@@ -9,7 +9,7 @@ use 5.010;  # //
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub import
 {
@@ -18,13 +18,14 @@ sub import
    $pkg->import_into( $caller, @_ );
 }
 
-my $default_adaptertype = "Null";
+my $adaptertype = "Null";
+my @adapterargs;
 
 sub import_into
 {
-   my ( $pkg, $caller, $type ) = @_;
+   my ( $pkg, $caller, @args ) = @_;
 
-   $default_adaptertype = $type if defined $type;
+   ( $adaptertype, @adapterargs ) = @args if @args;
 }
 
 my $adapter;
@@ -32,18 +33,14 @@ my $adapter;
 sub adapter
 {
    shift;
-   my ( @args ) = @_;
-
-   warn "Too late to apply extra args" if @args and $adapter;
 
    return $adapter //= do {
-      my $type = $default_adaptertype;
-      my $class = "Metrics::Any::Adapter::$type";
+      my $class = "Metrics::Any::Adapter::$adaptertype";
       unless( $class->can( 'new' ) ) {
          ( my $file = "$class.pm" ) =~ s{::}{/}g;
          require $file;
       }
-      $class->new( @args );
+      $class->new( @adapterargs );
    };
 }
 
