@@ -8,7 +8,7 @@ package Metrics::Any::Adapter::Null;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -31,12 +31,15 @@ sub new
    return bless {}, $class;
 }
 
-sub make_counter
-{
-}
-
-sub inc_counter
-{
+# All of these are empty methods
+foreach my $method (qw(
+   make_counter      inc_counter_by
+   make_distribution inc_distribution_by
+   make_gauge        inc_gauge_by  set_gauge_to
+   make_timer        inc_timer_by
+)) {
+   no strict 'refs';
+   *$method = sub {};
 }
 
 =head1 AUTHOR
